/*
 * Copyright (c) 2014 Cloudera, Inc. All rights reserved.
 */

package org.apache.hadoop.crypto.key.kms.server;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.hadoop.conf.Configuration;
import org.apache.hadoop.crypto.key.KeyProvider;
import org.apache.hadoop.crypto.key.KeyProviderFactory;

import javax.servlet.ServletContextEvent;
import javax.servlet.ServletContextListener;
import java.io.IOException;
import java.util.List;

/**
 * Unused start of a WebApp (ServletContextListener) for the TrusteeRestApi. Currently unused.
 * Needed if hot-reloading of TrusteeACLs is desired (currently unsupported). Based on
 * org.apache.hadoop.crypto.key.kms.server.KMSWebApp.
 */
public class TrusteeWebApp implements ServletContextListener {

  private static final Log LOG = LogFactory.getLog(TrusteeWebApp.class);

  private static Configuration kmsConf;

  @Override
  public void contextInitialized(ServletContextEvent servletContextEvent) {

    kmsConf = KMSConfiguration.getKMSConf();

  }

  public static KeyProvider getKeyProvider() throws IOException {
    List<KeyProvider> providers = KeyProviderFactory.getProviders(kmsConf);
    if (providers.isEmpty()) {
      throw new IllegalStateException("No KeyProvider has been defined");
    }
    if (providers.size() > 1) {
      LOG.warn("There is more than one KeyProvider configured '{" + kmsConf.get(KeyProviderFactory.KEY_PROVIDER_PATH) +
              "}', using the first provider");
    }
    return providers.get(0);
  }

  @Override
  public void contextDestroyed(ServletContextEvent servletContextEvent) {

  }
}
